

myWdataclean2<-function (z, wt = rep(1, length(z))) {
  #sort z,wt (ascending) wrt z
  niceorder <- order(z)
  sortedz <- z[niceorder]
  
  sortedw <- wt[niceorder]
  #store length of sortedd in n
  n <- length(sortedz)
  #y checks for jumps in sortedz using offsets of sortedz
  y <- sortedz[-1] != sortedz[-n]
  
  #ind stores jump indices (final index will be n)
  ind <- c(which(y | is.na(y)), n)
  
  #csum is cumulative sum of the weights
  csumw <- cumsum(sortedw)
  
  #value contains the (unique) obs in sortedz
  #dd contains the status of obs in sortedz
  #weight has the weights of the obs in sortedz
  list(value = sortedz[ind], weight = diff(c(0,csumw[ind])))
}




###################################################################
# myfun5 is a function for smoothing the cumulative dist fun F(X < theta)
###################################################################
myfun5 <- function(x, theta, eps) {
  u <- (x-theta)*sqrt(5)/eps
  INDE <- (u < sqrt(5)) & (u > -sqrt(5))
  u[u >= sqrt(5)] <- 0
  u[u <= -sqrt(5)] <- 1
  y <- 0.5 - (u - (u)^3/15)*3/(4*sqrt(5))
  u[ INDE ] <- y[ INDE ]
  return(u)
}


#$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$#
#$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$#
#$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$#
#pAUC on [p1, p2]
#$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$#
#$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$#
#$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$#

###################################################################
# mean.pauc is a function for (Y > X)I(lowx < X <= highx)
# mean.pauc returns a maxtrix with dimensions of length(X) by length(Y) 
# mean.pauc calls myfun5
# Y is a diseased sample
# X is a non diseased sample
# [lowx, highx] is X range for the partial AUC
# lowx is the (1 - p2)th quantile of X sample
# high is the (1 - p1)th quantile of X sample
# [p1, p2] is the range of FPR of the pAUC
###################################################################

mean.pauc<- function(x, lowx, highx, eps, y){
  outer(x, y, FUN="<")* ((1-myfun5(x, lowx, eps)) * myfun5(x, highx, eps))
}


##############################################################################
# eltest2u is a function to call el.test in package "emplik" to compute -2LLR by 
# assuming a fixed mean vector (mu) when Y probability equals to vvec
# eltest2u also returns X probability that minimizes -2LLR
# ab is a vector with 2 elements for the X range of the partial AUC. ab[1] < ab[2]
# x.sample is a non diseased sample
# y is a diseased sample
# mu is a vector with 3 elements (1-p2, 1-p1, pAUC)
# vvec is generally assumed as empirical distribution of Y sample.
##############################################################################
eltest2u <- function(ab = vector("numeric",2), x.sample, mu, y, vvec, eps )
{
  #eps <- 1/length(x.sample)
  
  axb <- matrix(c(myfun5(x.sample, ab[1], eps), myfun5(x.sample, ab[2], eps), mean.pauc(x.sample, ab[1], ab[2], eps, y)%*%vvec), ncol=3)
  
  all <- el.test(axb, mu)
  
  list('-2LLR'=all$`-2LLR`, uvec=all$wts)
}

##############################################################################
# eltest2v is a function to call el.test in package "emplik" to compute -2LLR with  
# a fixed partial pAUC at X probability equals to uvec
# ab is a vector with 2 elements for the X range of the partial AUC. ab[1] < ab[2]
# x.sample is a non diseased sample
# y is a diseased sample
# mu is pAUC
# uvec is generally returned from eltest2u
##############################################################################
eltest2v <- function(ab = vector("numeric",2), x.sample, mu, y, uvec, eps )
{
  #eps <- 1/length(x.sample)
  
  axb <- matrix(uvec%*%mean.pauc(x.sample, ab[1], ab[2], eps, y), ncol=1)
  
  all <- el.test(axb, mu)
  
  list('-2LLR'=all$`-2LLR`, vvec=all$wts)
}


#$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$#
#$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$#
#$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$#
#pAUC on [p1, 1] or [0, p2]
#$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$#
#$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$#
#$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$#
###################################################################
# mean.paucp1 is a function for (Y > X)I(X <= highx), which is the pAUC at [p1, 1]
# mean.paucp1 returns a maxtrix with dimensions of length(X) by length(Y) 
# mean.paucp1 calls myfun5
# Y is a diseased sample
# X is a non diseased sample
# (-inf, highx] is X range for the partial AUC
# highx is the (1 - p1)th quantile of X sample
###################################################################

mean.paucp1<- function(x, highx, eps, y){
  outer(x, y, FUN="<=")* myfun5(x, highx, eps)
}

###################################################################
# mean.paucp2 is a function for (Y > X)I(X > lowx), which is the pAUC at [0, p2]
# mean.paucp2 returns a maxtrix with dimensions of length(X) by length(Y) 
# mean.paucp2 calls myfun5
# Y is a diseased sample
# X is a non diseased sample
# [lowx, inf) is X range for the partial AUC
# lowx is the (1 - p2)th quantile of X sample
###################################################################

mean.paucp2<- function(x, lowx, eps, y){
  outer(x, y, FUN="<")* (1 - myfun5(x, lowx, eps))
}


##################################################################################################
# eltest2up12 is a function to call el.test in package "emplik" to compute -2LLR by 
# assuming a fixed mean vector (mu) when Y probability equals to vvec
# eltest2up12 also returns X probability that minimizes -2LLR
# mean.fun is mean.paucp1 or mean.paucp2, which is chosen based on the pAUC at [p1, 1] or [0, p2]
# mu is a vector with 2 elements (1-p1, pAUC) or (1-p2, pAUC)
# x.sample is a non diseased sample
# y is a diseased sample
# vvec is generally assumed as empirical distribution of Y sample
# highx is the (1 - p1)th quantile or the (1 - p2)th quantile
##################################################################################################
eltest2up12 <- function(mean.fun, x.sample, highx, mu, y, vvec, eps, ... )
{
#  eps <- 1/length(x.sample)
  
  axb <- matrix(c(myfun5(x.sample, highx, eps), mean.fun(x.sample, highx, eps, y)%*%vvec), ncol=2)
  #axb <- matrix(c(1-myfun5(x.sample, highx, eps), mean.fun(x.sample, highx, eps, y)%*%vvec), ncol=2)
  
  all <- el.test(axb, mu)
  
  list('-2LLR'=all$`-2LLR`, uvec=all$wts)
}

#################################################################################################
# eltest2vp12 is a function to call el.test in package "emplik" to compute -2LLR with  
# a fixed partial pAUC at X probability equals to uvec
# mean.fun is mean.paucp1 or mean.paucp2, which is chosen based on the pAUC at [p1, 1] or [0, p2]
# x.sample is a non diseased sample
# y is a diseased sample
# mu is pAUC
# uvec is generally returned from eltest2up12
# highx is the (1 - p1)th quantile or the (1 - p2)th quantile
#################################################################################################
eltest2vp12 <- function(mean.fun, x.sample, highx, mu, y, uvec, eps, ... )
{
#  eps <- 1/length(x.sample)
  
  axb <- matrix(uvec%*%mean.fun(x.sample, highx, eps, y), ncol=1)
  
  all <- el.test(axb, mu)
  
  list('-2LLR'=all$`-2LLR`, vvec=all$wts)
}

#$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$#
#$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$#
#$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$#
#Whole AUC
#$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$#
#$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$#
#$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$#


###################################################################
# mean.whole is a function for (Y > X), which is the AUC at [0, 1]
# mean.whole returns a maxtrix with dimensions of length(X) by length(Y) 
# Y is a diseased sample
# X is a non diseased sample
###################################################################
mean.whole<- function(x, y){
  outer(x, y, FUN="<")
}

##################################################################################################
# eltest2u.all is a function to call el.test in package "emplik" to compute -2LLR by 
# assuming a fixed mean AUC (mu) when Y probability equals to vvec
# eltest2u.all also returns X probability that minimizes -2LLR
# mu is the AUC
# x.sample is a non diseased sample
# y is a diseased sample
# vvec is generally assumed as empirical distribution of Y sample
##################################################################################################

eltest2u.all <- function(x.sample, mu, y, vvec )
{
  
  all <- el.test(mean.whole(x.sample,  y)%*%vvec, mu)
  
  list('-2LLR'=all$`-2LLR`, uvec=all$wts)
}
#################################################################################################
# eltest2v.all is a function to call el.test in package "emplik" to compute -2LLR with  
# a fixed pAUC at X probability equals to uvec
# x.sample is a non diseased sample
# y is a diseased sample
# mu is pAUC
# uvec is generally returned from eltest2up12
#################################################################################################

eltest2v.all <- function(x.sample, mu, y, uvec )
{
  
  axb <- matrix(uvec%*%mean.whole(x.sample,  y), ncol=1)
  
  all <- el.test(axb, mu)
  
  list('-2LLR'=all$`-2LLR`, vvec=all$wts)
}

####################################################################################################
# eltest2step.all is a function to search the minimum of -2LLR by Golden Section Search method
# eltest2step.all calls both eltest2u.all and eltest2v.all and returns the minimum summation of -2LLR
# from eltest2u.all and eltest2v.all
# nx is the sample size of X
# x is a non diseased sample
# ny is the sample size of Y
# y is a diseased sample
# true is the AUC to be tested
####################################################################################################

