\name{est.pAUC}
\alias{est.pAUC}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Estimate pAUC/AUC by a non-parametric method
}
\description{
The formula for pAUC at p=(p1, p2), 0 < p1 < p2 < 1 is in the details. 
For pAUC at p=[0, p2), the indicator functon in the formula is changed to I(x > t2); 
for pAUC at p=(p1, 1], the indicator function in the formula is changed to I(x < t1); 
for AUC, the indicator function is removed from the formula.
}
\usage{
est.pAUC(x, y, p, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{
x is a sample of test results for non-diseased population.
}
  \item{y}{
y is a sample of test results for diseased population.
}
  \item{p}{
a vector with two elements:
p=(p1, p2) for pAUC at (p1, p2), \eqn{0 \le p1 < p2 \le 1}; p = (0, 1) for AUC.
}
  \item{\dots}{
there is an additional argument 'eps' for pAUCs; there is no addtional arguments for AUC.
}
}
\details{ 
The estimator is
\eqn{\widehat{pAUC}=\frac{1}{mn}\sum_{i=1}^m\sum_{j=1}^n I(y_j \geq x_i)I( x_i \in (t_1 , t_2))}
where \eqn{X_1, X_2, \cdots, X_m} are the test results of above non-disease samples and 
\eqn{Y_1, Y_2, \cdots, Y_n} are the test results of the disease samples. 
\eqn{t_1= \hat{F}^{-1}(1-p_2)= \sup \{t: \hat{F}(t) \le 1-p_2 \}; 
     t_2= \hat{F}^{-1}(1-p_1)= \sup \{t: \hat{F}(t) \le 1-p_1 \}}. 
}
\value{
the returned value is the estimate of pAUC/AUC.
}
\references{
Dodd LE and Pepe MS; Partial AUC Estimation and Regression; Biometrics; 2003; 59; 614-623.
}
\author{
Yumin Zhao
}
%\note{
%%  ~~further notes~~
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

%\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
%}
\examples{
### An example for pAUC at (0.05, 0.55)
nx <- 50
rate.x <- 1
ny <- 50
rate.y <- 0.25
p1 <- 0.05
p2 <- 0.55
eps <- 1/nx
x <- rexp(nx, rate.x)
y <- rexp(ny, rate.y)

est.pAUC(x, y, p=c(p1, p2), eps=eps)

### An example for pAUC at (0, 0.45)
nx <- 50
ny <- 40
p1 <- 0
p2 <- 0.45
x <- rnorm(nx)
y <- rnorm(ny, 2, 1)
eps <- 1/nx

est.pAUC(x, y, p=c(p1, p2), eps=eps)

### An example for pAUC at (0.45, 1)
nx <- 100
ny <- 80
p1 <- 0.45
p2 <- 1
x <- rnorm(nx)
y <- rnorm(ny, 2, 1)
eps <- 1/nx

est.pAUC(x, y, p=c(p1, p2), eps=eps)

### An example for AUC
nx <- 40
ny <- 30
x <- rnorm(nx)
y <- rnorm(ny, 1, 1)

est.pAUC(x, y, p=c(0, 1))
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
%\keyword{ ~kwd1 }
%\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
