\name{neighb.p.lc}
\alias{neighb.p.lc}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Empirical likelihood test for Lorenz Curve
}
\description{
Compute the empirical likelihood ratio with the Lorenz Curve fixed at \eqn{LC_p}
}
\usage{
neighb.p.lc(p, x, true, eps)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{p}{
the truncated quantile, \eqn{0 < p < 1}.
}
  \item{x}{
a random sample
}
  \item{true}{
the Lorenz Curve to be tested
}
  \item{eps}{
a smoothing parameter
}
}
\details{
The empirical likehihood ratio test for Lorenz Curve at [0, p) is executed in two steps. 
First, test the hypotheses with two parameters, one of which is the nuisance parameters p. 
Second, profile out the nuisance paramter p. This function performs the second step - profiling out the nuisance paramter. 
This function seaches the minimum of the empirical likehihood ratio test statistics along the consecutive sample points. 
Since the test statistics is a piecewise constant function of the quantile for p, 
the minimum is easily found if the searching starts at the sample p-th quantile.  
}
\value{
\item{"-2LLR"}{the -2 loglikelihood ratio; approximate chi square distribution with one degree of freedom under H0}
\item{Pval}{the observed P-value by chi square approximation}
}
%\references{
%% ~put references to the literature/web site here ~
%}
\author{
Yumin Zhao
}
%\note{
%%  ~~further notes~~
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

%\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
%}
\examples{
set.seed(123)

nsize <- 50

p<- 0.89

rate <- 0.25

q <- qexp(p, rate)

rp_glc <- function(x){
  y <- x*dexp(x, rate=0.25)
  y
}

omu_glc <- integrate(rp_glc, lower= 0, upper=q)$value
mu_lc <- omu_glc*rate

x <- rexp(n=nsize, rate=rate)
  
neighb.p.lc(p, x, mu_lc, eps=1/nsize)
}

% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
%\keyword{ ~kwd1 }
%\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
