\name{neighb.xy}
\alias{neighb.xy}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Empirical likelihood test for pAUC at (p1, p2)
}
\description{
Compute the empirical likelihood ratio with pAUC fixed at \eqn{pAUC_0}
}
\usage{
neighb.xy(sp12 = vector("numeric", 2), x, y, true, tol = 0.001, eps)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{sp12}{
a vector of two False Positive Rates between which the pAUC is tested, sp12=(p1, p2)
}
  \item{x}{
a sample of test results from non-diseased population
}
  \item{y}{
a sample of test results from diseased population
}
  \item{true}{
the pAUC to be tested
}
  \item{tol}{
the maximum distance between the current guess and the current range on Golden Section Search Optimization method
}
  \item{eps}{
a smoothing parameter
}
}
\details{
The empirical likehihood ratio test for pAUC at (p1, p2) is executed in two steps. First, 
test the hypotheses with three parameters, two of which are the nuisance parameters p1 and p2. 
Second, profile out the nuisance paramters p1 and p2. This function performs the second 
step - profiling out the nuisance paramters. This function seaches the minimum of 
the empirical likehihood ratio test statistics among combinations of (1 - p1)-th quantile 
and (1 - p2)-th quantile with (1 - p1)-th quantile and (1 - p2)-th quantile moving along 
the consecutive non-diseased sample points seperately. Since the test statistics is a piecewise 
constant function of the quantiles for (1 - p1) and (1 - p2), the minimum is easily found if 
searching starts at some strategical quantiles such as the sample quantiles at (1 - p1) and (1 - p2). 
}
\value{
\item{"-2LLR"}{the -2 loglikelihood ratio; approximate chisq distribution under H0}
\item{Pval}{the observed P-value by chi-square approximation}
}
\references{
The Paritial Area Under ROC Curves by Empirical Likelihood Method
}
\author{
Yumin Zhao
}
%\note{
%%  ~~further notes~~
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

%\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
%}
\examples{
mux <- 0
stddx <- 1
muy <- 1
stddy <- 1

p1 <- 0.05 
p2 <- 0.5
  
  rp<-function(p, mux, stddx, muy, stddy)
  {
    y<-1-pnorm(qnorm(1-p, mux, stddx), muy, stddy)
    y
  }
##ture pAUC at (p1, p2)  
 truepauc<-integrate(rp, mux=mux, stddx=stddx, muy=muy, stddy=stddy,lower=p1,upper=p2)$value
    
nx <- 40
ny <- 30
   
x <- rnorm(nx, mux, stddx)
y <- rnorm(ny, muy, stddy)   
neighb.xy(sp12=c(p1, p2), x=x, y=y, true=truepauc, tol=0.001, eps=1/nx)

}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
%\keyword{ ~kwd1 }
%\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
